@@ -5,9 +5,7 @@
 #include "msa.h"
 #include "tree.h"
 #include "profile.h"
-
-extern void MHackStart(SeqVect &v);
-extern void MHackEnd(MSA &msa);
+#include "timing.h"
 
 static char g_strUseTreeWarning[] =
 "\n******** WARNING ****************\n"
@@ -17,11 +15,10 @@ static char g_strUseTreeWarning[] =
 "please refer to the user guide. To disable this\n"
 "warning, use -usetree_nowarn <treefilename>.\n\n";
 
-static void Muscle()
+void DoMuscle()
 	{
-	SetOutputFileName(g_pstrInFileName);
+	SetOutputFileName(g_pstrOutFileName);
 	SetInputFileName(g_pstrInFileName);
-	SetStartTime();
 
 	SetMaxIters(g_uMaxIters);
 	SetSeqWeightMethod(g_SeqWeight1);
@@ -45,8 +42,12 @@ static void Muscle()
 		Alpha = ALPHA_Amino;
 		break;
 
-	case SEQTYPE_Nucleo:
-		Alpha = ALPHA_Nucleo;
+	case SEQTYPE_DNA:
+		Alpha = ALPHA_DNA;
+		break;
+
+	case SEQTYPE_RNA:
+		Alpha = ALPHA_RNA;
 		break;
 
 	default:
@@ -55,14 +56,28 @@ static void Muscle()
 	SetAlpha(Alpha);
 	v.FixAlpha();
 
-	if (ALPHA_Nucleo == Alpha)
+	PTR_SCOREMATRIX UserMatrix = 0;
+	if (0 != g_pstrMatrixFileName)
 		{
-		SetPPScore(PPSCORE_SPN);
-		g_Distance1 = DISTANCE_Kmer4_6;
+		const char *FileName = g_pstrMatrixFileName;
+		const char *Path = getenv("MUSCLE_MXPATH");
+		if (Path != 0)
+			{
+			size_t n = strlen(Path) + 1 + strlen(FileName) + 1;
+			char *NewFileName = new char[n];
+			sprintf(NewFileName, "%s/%s", Path, FileName);
+			FileName = NewFileName;
+			}
+		TextFile File(FileName);
+		UserMatrix = ReadMx(File);
+		g_Alpha = ALPHA_Amino;
+		g_PPScore = PPSCORE_SP;
 		}
 
-	if (g_bVerbose)
-		ListParams();
+	SetPPScore();
+
+	if (0 != UserMatrix)
+		g_ptrScoreMatrix = UserMatrix;
 
 	unsigned uMaxL = 0;
 	unsigned uTotL = 0;
@@ -87,9 +102,6 @@ static void Muscle()
 	for (unsigned uSeqIndex = 0; uSeqIndex < uSeqCount; ++uSeqIndex)
 		v.SetSeqId(uSeqIndex, uSeqIndex);
 
-	if (uSeqCount > 1)
-		MHackStart(v);
-
 	if (0 == uSeqCount)
 		Quit("Input file '%s' has no sequences", g_pstrInFileName);
 	if (1 == uSeqCount)
@@ -99,6 +111,9 @@ static void Muscle()
 		return;
 		}
 
+	if (uSeqCount > 1)
+		MHackStart(v);
+
 // First iteration
 	Tree GuideTree;
 	if (0 != g_pstrUseTreeFileName)
@@ -161,13 +176,22 @@ static void Muscle()
 		ProgressiveAlign(v, GuideTree, msa);
 	SetCurrentAlignment(msa);
 
+	if (0 != g_pstrComputeWeightsFileName)
+		{
+		extern void OutWeights(const char *FileName, const MSA &msa);
+		SetMSAWeightsMuscle(msa);
+		OutWeights(g_pstrComputeWeightsFileName, msa);
+		return;
+		}
+
 	ValidateMuscleIds(msa);
 
 	if (1 == g_uMaxIters || 2 == uSeqCount)
 		{
-		TextFile fileOut(g_pstrOutFileName, true);
-		MHackEnd(msa);
-		msa.ToFile(fileOut);
+		//TextFile fileOut(g_pstrOutFileName, true);
+		//MHackEnd(msa);
+		//msa.ToFile(fileOut);
+		MuscleOutput(msa);
 		return;
 		}
 
@@ -200,7 +224,6 @@ static void Muscle()
 	else
 		RefineHoriz(msa, GuideTree, g_uMaxIters - 2, false, false);
 
-
 #if	0
 // Refining by subfamilies is disabled as it didn't give better
 // results. I tried doing this before and after RefineHoriz.
@@ -211,20 +234,32 @@ static void Muscle()
 	ValidateMuscleIds(msa);
 	ValidateMuscleIds(GuideTree);
 
-	TextFile fileOut(g_pstrOutFileName, true);
-	MHackEnd(msa);
-	msa.ToFile(fileOut);
+	//TextFile fileOut(g_pstrOutFileName, true);
+	//MHackEnd(msa);
+	//msa.ToFile(fileOut);
+	MuscleOutput(msa);
 	}
 
 void Run()
 	{
+	SetStartTime();
 	Log("Started %s\n", GetTimeAsStr());
 	for (int i = 0; i < g_argc; ++i)
 		Log("%s ", g_argv[i]);
 	Log("\n");
 
+#if	TIMING
+	TICKS t1 = GetClockTicks();
+#endif
 	if (g_bRefine)
 		Refine();
+	else if (g_bRefineW)
+		{
+		extern void DoRefineW();
+		DoRefineW();
+		}
+	else if (g_bProfDB)
+		ProfDB();
 	else if (g_bSW)
 		Local();
 	else if (0 != g_pstrSPFileName)
@@ -233,8 +268,31 @@ void Run()
 		Profile();
 	else if (g_bPPScore)
 		PPScore();
+	else if (g_bPAS)
+		ProgAlignSubFams();
 	else
-		Muscle();
+		DoMuscle();
+
+#if	TIMING
+	extern TICKS g_ticksDP;
+	extern TICKS g_ticksObjScore;
+	TICKS t2 = GetClockTicks();
+	TICKS TotalTicks = t2 - t1;
+	TICKS ticksOther = TotalTicks - g_ticksDP - g_ticksObjScore;
+	double dSecs = TicksToSecs(TotalTicks);
+	double PctDP = (double) g_ticksDP*100.0/(double) TotalTicks;
+	double PctOS = (double) g_ticksObjScore*100.0/(double) TotalTicks;
+	double PctOther = (double) ticksOther*100.0/(double) TotalTicks;
+	Log("                 Ticks     Secs    Pct\n");
+	Log("          ============  =======  =====\n");
+	Log("DP        %12ld  %7.2f  %5.1f%%\n",
+	  (long) g_ticksDP, TicksToSecs(g_ticksDP), PctDP);
+	Log("OS        %12ld  %7.2f  %5.1f%%\n",
+	  (long) g_ticksObjScore, TicksToSecs(g_ticksObjScore), PctOS);
+	Log("Other     %12ld  %7.2f  %5.1f%%\n",
+	  (long) ticksOther, TicksToSecs(ticksOther), PctOther);
+	Log("Total     %12ld  %7.2f  100.0%%\n", (long) TotalTicks, dSecs);
+#endif
 
 	ListDiagSavings();
 	Log("Finished %s\n", GetTimeAsStr());
