@@ -52,16 +52,7 @@ double GetMemUseMB()
 
 	int fd = open(statm, O_RDONLY);
 	if (-1 == fd)
-		{
-		static bool Warned = false;
-		if (!Warned)
-			{
-			Warned = true;
-			Warning("*Warning* Cannot open %s errno=%d %s",
-			  statm, errno, strerror(errno));
-			}
-		return 0;
-		}
+		return -1;
 	char Buffer[64];
 	int n = read(fd, Buffer, sizeof(Buffer) - 1);
 	close(fd);
