@@ -1,9 +1,10 @@
 #include "muscle.h"
 #include <stdio.h>
 #ifdef	WIN32
-#include <io.h>	// for isatty()
+#include <windows.h>	// for SetPriorityClass()
+#include <io.h>			// for isatty()
 #else
-#include <unistd.h>	// for isatty()
+#include <unistd.h>		// for isatty()
 #endif
 
 int g_argc;
@@ -11,6 +12,13 @@ char **g_argv;
 
 int main(int argc, char **argv)
 	{
+#if	WIN32
+// Multi-tasking does not work well in CPU-bound
+// console apps running under Win32.
+// Reducing the process priority allows GUI apps
+// to run responsively in parallel.
+	SetPriorityClass(GetCurrentProcess(), BELOW_NORMAL_PRIORITY_CLASS);
+#endif
 	g_argc = argc;
 	g_argv = argv;
 
@@ -20,6 +28,10 @@ int main(int argc, char **argv)
 	SetParams();
 	SetLogFile();
 
+	//extern void TestSubFams(const char *);
+	//TestSubFams(g_pstrInFileName);
+	//return 0;
+
 	if (g_bVersion)
 		{
 		printf(MUSCLE_LONG_VERSION "\n");
