@@ -22,7 +22,9 @@ static VALUE_OPT ValueOpts[] =
 	"MaxIters",			0,
 	"MaxHours",			0,
 	"GapOpen",			0,
+	"GapOpen2",			0,
 	"GapExtend",		0,
+	"GapExtend2",		0,
 	"GapAmbig",			0,
 	"Center",			0,
 	"SmoothScoreCeil",	0,
@@ -30,6 +32,12 @@ static VALUE_OPT ValueOpts[] =
 	"MinSmoothScore",	0,
 	"ObjScore",			0,
 	"SmoothWindow",		0,
+	"RefineWindow",		0,
+	"FromWindow",		0,
+	"ToWindow",			0,
+	"SaveWindow",		0,
+	"WindowOffset",		0,
+	"FirstWindow",		0,
 	"AnchorSpacing",	0,
 	"Log",				0,
 	"LogA",				0,
@@ -55,6 +63,18 @@ static VALUE_OPT ValueOpts[] =
 	"SPScore",			0,
 	"SeqType",			0,
 	"MaxMB",			0,
+	"ComputeWeights",	0,
+	"MaxSubFam",		0,
+	"ScoreFile",		0,
+	"TermGaps",			0,
+	"FASTAOut",			0,
+	"CLWOut",			0,
+	"CLWStrictOut",		0,
+	"HTMLOut",			0,
+	"MSFOut",			0,
+	"PHYIOut",			0,
+	"PHYSOut",			0,
+	"Matrix",			0,
 	};
 static int ValueOptCount = sizeof(ValueOpts)/sizeof(ValueOpts[0]);
 
@@ -64,9 +84,6 @@ static FLAG_OPT FlagOpts[] =
 	"SP",					false,
 	"SV",					false,
 	"SPN",					false,
-	"TermGapsHalf",			false,
-	"TermGapsHalfLonger",	false,
-	"TermGapsFull",			false,
 	"Core",					false,
 	"NoCore",				false,
 	"Diags1",				false,
@@ -78,11 +95,11 @@ static FLAG_OPT FlagOpts[] =
 	"Anchors",				false,
 	"NoAnchors",			false,
 	"Refine",				false,
+	"RefineW",				false,
 	"SW",					false,
 	"Profile",				false,
 	"PPScore",				false,
 	"Cluster",				false,
-	"TermGaps4",			false,
 	"Brenner",				false,
 	"Dimer",				false,
 	"clw",					false,
@@ -92,6 +109,10 @@ static FLAG_OPT FlagOpts[] =
 	"Stable",				false,
 	"Group",				false,
 	"FASTA",				false,
+	"ProfDB",				false,
+	"PAS",					false,
+	"PHYI",					false,
+	"PHYS",					false,
 	};
 static int FlagOptCount = sizeof(FlagOpts)/sizeof(FlagOpts[0]);
 
