@@ -38,6 +38,9 @@ const char *ElapsedTimeAsStr()
 
 const char *MemToStr(double MB)
 	{
+	if (MB < 0)
+		return "";
+
 	static char Str[9];
 	static double MaxMB = 0;
 	static double RAMMB = 0;
@@ -108,6 +111,29 @@ static void Wipe(int n)
 		fprintf(g_fProgress, " ");
 	}
 
+void Progress(const char *szFormat, ...)
+	{
+	CheckMaxTime();
+
+	if (g_bQuiet)
+		return;
+
+	double MB = GetCheckMemUseMB();
+
+	char szStr[4096];
+	va_list ArgList;
+	va_start(ArgList, szFormat);
+	vsprintf(szStr, szFormat, ArgList);
+
+	fprintf(g_fProgress, "\n%8.8s  %12s                    %s",
+	  ElapsedTimeAsStr(),
+	  MemToStr(MB),
+	  szStr);
+
+	fprintf(g_fProgress, "\n");
+	fflush(g_fProgress);
+	}
+
 void Progress(unsigned uStep, unsigned uTotalSteps)
 	{
 	CheckMaxTime();
